==> FlexOS_286_1.3_Dev_Kit.zip: cnfg_src/sysbuild.h <==
/******************************************************************************
* SYSBUILD.H - Compile Time Options				Version 1.3.02
*******************************************************************************
* Copyright (c) 1985, Digital Research, Inc. All Rights Reserved. The Software
* Code contained in this listing is proprietary to Digital Research, Inc.,
* Monterey, California and is covered by U.S. and other copyright protection.
* Unauthorized copying, adaptation, distribution, use or display is prohibited
* and may be subject to civil and criminal penalties.  Disclosure to others is
* prohibited.  For the terms and conditions of software code use refer to the
* appropriate Digital Research License Agreement.
*******************************************************************************
* Version   Date   Who  Description
* ======= ======== ===  =======================================================
* v1.3.02 11/13/86 AM	Added ASMTERM for assembly language stack switch code.
* v1.3.01 09/26/86 AM	Removed AM_FIX (new mrange is conditoned with IAPX286).
* v1.3.00 09/16/86 ldt  Changed defines to assume meta-ware. 
* v1.2.04 09/08/86 AM	Added ASMNOBITS conditional.
* v1.2.03 08/18/86 AM	Added AM_FIX conditional (commented out)
*  1.2.02 08/04/86 mei  Added PROTOS.
* v1.2.01 04/15/86 FRH	Add ASMADUMMY
* v1.2.00 04/14/86 FRH	Creation
******************************************************************************/

	/* CPU */

#define MC68K		0		/* 1 = Motorola 68000 		*/
#define IAPX286 	1		/* 1 = Intel 286 Protected Mode	*/
#define IAPX186 	0		/* 1 = Intel 186, 286 Real Mode	*/
#define IAPX86 		0		/* 1 = Intel 8086		*/
#define NECV60		0		/* 1 = NEC V60			*/

	/* C Compiler */

#define	LATTICE		0		/* 1 = Lattice (8086) Big Model	*/
#define METAWARE	0		/* 1 = Metaware Hi-C (286) Big	*/
#define ALCYON		0		/* 1 = Alcyon (68K)		*/

	/* Functional Prototype Option */

#define PROTOS		0		/* 1 = include functional prototypes */

/* Keyboard ASR Option */

#define KBBREAK		0	/* if 1, ` (backquote) causes breakpt */

	/* Timer/Tick Options */

#define	NEWTICK		1	/* If 1, use new tick system 		*/

	/* Async System Options */

#define EVCHECK		0	/* check for zeroed e_pred field in evremove */
#define ASRCHECK	1	/* check for zero ASRFREE list */
#define NEVTYPES	32	/* up to 32 unique event types supported */
				/* this determines the size of the ecan table*/

	/* Loader Options */

#define CLOADELF	1	/* If 1, use fast .286 loader */

	/* memory management options */

#define GDT_LIMIT 	0x29ff	/* Size of GDT Table */

	/* The defines of the form ASMXXXXX determine whether the	*/
	/*	routine XXXXX has been converted to assembler.		*/
	/*	If defined as 0, the C version is used; otherwise	*/
	/*	use the assembler version 				*/

#define	ASMDOASR	1
#define ASMZOMBIE	1
#define ASMASRINSERT	1
#define ASMNEXTASR	1
#define ASMEVINSERT	1
#define ASMEVREMOVE	1
#define ASMMXREL	1
#define ASMEVDONE	1
#define ASMSIGNAL	1
#define ASMRUNHIM	1
#define ASMASETUP	1
#define	ASMNODISP	1
#define ASMOKDISP 	1
#define ASMPINTON	1	/* 1 = ASM version of pinton()		     */
#define ASMDISP		1	/* 1 = ASM version of disp()		     */
#define ASMMIS		1	/* 1 = ASM Version of MISMAN I/O path	     */
#define ASMPIPE		1	/* 1 = ASM version of PIPEMAN for READ/WRITE */
#define	AFLAGSET	1	/* 1 = ASM version of flagset()		     */
#define AFLAGCLR	1	/* 1 = ASM version of flagclr()		     */
#define AFLAGEVENT	1	/* 1 = ASM version of flagevent()	     */
#define ASMADUMMY	1	/* 1 = ASM version of _adummy()		     */
#define	ASMNOBITS	1	/* 1 = ASM version of no_bits()		     */
#define	ASMTERM		1	/* 1 = ASM terminate() stack switch	     */

==> FlexOS_286_1.42_Dev_Kit.zip: cnfg_src/sysbuild.h <==
/******************************************************************************
* SYSBUILD.H - Compile Time Options				Version 1.4.01
*******************************************************************************
* Copyright (c) 1985, Digital Research, Inc. All Rights Reserved. The Software
* Code contained in this listing is proprietary to Digital Research, Inc.,
* Monterey, California and is covered by U.S. and other copyright protection.
* Unauthorized copying, adaptation, distribution, use or display is prohibited
* and may be subject to civil and criminal penalties.  Disclosure to others is
* prohibited.  For the terms and conditions of software code use refer to the
* appropriate Digital Research License Agreement.
*******************************************************************************
* Version    Date   Who Description
* ======= ========= === =======================================================
* v1.5.00 13-Nov-87 glp	Added define to make debugging loadable driver code
*			conditional.  Support is for 286 drivers only.
* v1.4.01 06/26/87 RFW	added ASRDIAG define to check asr entries are allocated
*			and freed properly.
* v1.4.00 05/29/87 AM	Added proper conditionals for IAPX386 beta.
* H386	  02/14/86 GLP	Added PAGEMEM
* H386	  12/15/86 GLP	Added IAPX386 (For 1st go, IAPX286 will be true also)
* v1.3.02 11/13/86 AM	Added ASMTERM for assembly language stack switch code.
* v1.3.01 09/26/86 AM	Removed AM_FIX (new mrange is conditoned with IAPX286).
* v1.3.00 09/16/86 ldt  Changed defines to assume meta-ware. 
* v1.2.04 09/08/86 AM	Added ASMNOBITS conditional.
* v1.2.03 08/18/86 AM	Added AM_FIX conditional (commented out)
*  1.2.02 08/04/86 mei  Added PROTOS.
* v1.2.01 04/15/86 FRH	Add ASMADUMMY
* v1.2.00 04/14/86 FRH	Creation
******************************************************************************/

#define COPYRIGHT  "Copyright (C) Digital Research Inc. 1985,1986,1987,1988\n\r";

	/* CPU */

#define MC68K		0		/* 1 = Motorola 68000 		*/
#define	IAPX386		0		/* 1 = Intel 386 Protected Mode	*/
#define IAPX286 	1		/* 1 = Intel 286 Protected Mode	*/
#define IAPX186 	0		/* 1 = Intel 186, 286 Real Mode	*/
#define IAPX86 		0		/* 1 = Intel 8086		*/
#define NECV60		0		/* 1 = NEC V60			*/

	/* DEBUG */
	
#if IAPX386 | IAPX286

	/* Define DRIVERSYMBOLS if you wish to debug loadable
	drivers from SASIDxxx  IE be able to use the drivers
	symbols.  Files that must be compiled are command.c,
	config.c and l286.c.					*/

$#define	DRIVERSYMBOLS

#endif

	/* MEMORY MODEL */

#if IAPX386 | NECV60
#define	PAGEMEM		1		/* Using New page memory code	*/
#else
#define	PAGEMEM		0		/* Using old memory code	*/
#endif

#define	SH_MEM		1		/* SHARED MEMORY */

	/* C Compiler */

#define	LATTICE		0		/* 1 = Lattice (8086) Big Model	*/
#define METAWARE	0		/* 1 = Metaware Hi-C (286) Big	*/
#define ALCYON		0		/* 1 = Alcyon (68K)		*/

	/* Diagnostics Options */ 

#define	CONTDIAG	0		/* 1 = Contig. memory check	*/
#define ASRDIAG		0		/* 1 = ASR allocation checks 	*/
/* NOTE: must also set ASRDIAG and ACTTABLE true in sysbuild.equ then   */
/* recompile config.c, async.c, async286.a86, and disp286.a86 to enable */
/* it. There is room for additional diagnostic info.			*/

	/* Functional Prototype Option */

#define PROTOS		0		/* 1 = include functional prototypes */

/* Keyboard ASR Option */

#define KBBREAK		1	/* if 1, ` (backquote) causes breakpt */

	/* Timer/Tick Options */

#define	NEWTICK		1	/* If 1, use new tick system 		*/

	/* Async System Options */

#define EVCHECK		0	/* check for zeroed e_pred field in evremove */
#define ASRCHECK	1	/* check for zero ASRFREE list */
#define NEVTYPES	32	/* up to 32 unique event types supported */
				/* this determines the size of the ecan table*/

	/* Loader Options */

#define CLOADELF	1	/* If 1, use fast .286 loader */

	/* memory management options */

#define GDT_LIMIT 	0x29ff	/* Size of GDT Table */

	/* The defines of the form ASMXXXXX determine whether the	*/
	/*	routine XXXXX has been converted to assembler.		*/
	/*	If defined as 0, the C version is used; otherwise	*/
	/*	use the assembler version 				*/

#define	ASMDOASR	1
#define ASMZOMBIE	1
#define ASMASRINSERT	1
#define ASMNEXTASR	1
#define ASMEVINSERT	1
#define ASMEVREMOVE	1
#define ASMMXREL	1
#define ASMEVDONE	1
#define ASMSIGNAL	1
#define ASMRUNHIM	1
#define ASMASETUP	1
#define	ASMNODISP	1
#define ASMOKDISP 	1
#define ASMPINTON	1	/* 1 = ASM version of pinton()		     */
#define ASMDISP		1	/* 1 = ASM version of disp()		     */
#define ASMMIS		1	/* 1 = ASM Version of MISMAN I/O path	     */
#define ASMPIPE		1	/* 1 = ASM version of PIPEMAN for READ/WRITE */
#define	AFLAGSET	1	/* 1 = ASM version of flagset()		     */
#define AFLAGCLR	1	/* 1 = ASM version of flagclr()		     */
#define AFLAGEVENT	1	/* 1 = ASM version of flagevent()	     */
#define ASMADUMMY	1	/* 1 = ASM version of _adummy()		     */
#define	ASMNOBITS	1	/* 1 = ASM version of no_bits()		     */
#define	ASMTERM		1	/* 1 = ASM terminate() stack switch	     */

